<?php

class AccessControlManager {
	
	const PASSWORDBACKEND_LOCAL = "local";
	const PASSWORDBACKEND_LDAP = "ldap";
	const PASSWORDBACKEND_AD = "ad";
	
	static $instance;
	private $db;
	
	private $cache;
	
	
	public function __construct() {
		$this->cache = array();
		
		$dbRoot = ServerConfig::getDatabasePath() . "../general/";
		$dbFile = realpath($dbRoot) . "/system.s3db";
		
		if (!file_exists($dbFile)) {
			
			// Check if we are able to create it
 			$isWriteAble = @fopen($dbFile, 'w');
			if ($isWriteAble === false) die("Can't create/write to database file: " . $dbFile);
			fclose($isWriteAble);			
			
			// Create databasefile
			$this->db = new PDO("sqlite:" . $dbFile);
			
			if (!$this->db) {
				die("Can't create new database file: " . $dbFile);
			}
			
			// Read SQL statmens, that create the main structure
			$sql_1 = file_get_contents($dbRoot . "sql/1.sql");
			$sql_2 = file_get_contents($dbRoot . "sql/2.sql");
			$sql_3 = file_get_contents($dbRoot . "sql/3.sql");
			$sql_4 = file_get_contents($dbRoot . "sql/4.sql");
			$sql_5 = file_get_contents($dbRoot . "sql/5.sql");
			$sql_6 = file_get_contents($dbRoot . "sql/6.sql");
			$sql_7 = file_get_contents($dbRoot . "sql/7.sql");
			
			// Execute SQL
			$this->db->exec($sql_1);
			$this->db->exec($sql_2);
			$this->db->exec($sql_3);
			$this->db->exec($sql_4);
			$this->db->exec($sql_5);
			$this->db->exec($sql_6);
			$this->db->exec($sql_7);
				
		} else {
			$this->db = new PDO("sqlite:" . $dbFile);
		}
		
		self::$instance = $this;
	}
	
	
	public function __destruct() {
		
	}
	
	static function getInstance() {
		if (empty(self::$instance)) {
			self::$instance = new AccessControlManager();
		}
		return self::$instance;
	}

	/**
	 * Return all users
	 * 
	 * @return array Returns an array with users
	 */
	public function getUsers() {				
		$users = array();
		$sql = "SELECT * FROM Users ORDER BY name";
		foreach ($this->db->query($sql) as $row) {
			$users[] = new User($row[0], $row[1], $row[2], $row[3], $row[4], $row[5], $row[6], $row[7], $row[8], $row[9], $row[10]);
		}
		return $users;		
	}
	
	public function getUser($id = null, $username = null) {	
		if (!empty($id)) {			
			$sql = "SELECT * FROM Users WHERE id = " . $id;
		} else if (!empty($username)) {			
			$sql = "SELECT * FROM Users WHERE username = '" . $username . "'";
		} else {
			return null;
		}
		foreach ($this->db->query($sql) as $row) {
			return new User($row[0], $row[1], $row[2], $row[3], $row[4], $row[5], $row[6], $row[7], $row[8], $row[9], $row[10]);
		}
		return null;
	}
	

	
	public function getGroups() {		
		$groups = array();		
		$sql = "SELECT id, name, description FROM Groups ORDER BY name";		
		foreach ($this->db->query($sql) as $row) {
			$groups[] = new Group($row[0], $row[1], $row[2]);
		}
		return $groups;
	}
	
	public function getGroup($id = null, $name = null) {	

		if (!empty($id)) {
			$sql = "SELECT id, name, description FROM Groups WHERE id = " . $id;
		} else if (!empty($name)) {
			$sql = "SELECT id, name, description FROM Groups WHERE name = '" . $name . "'";
		} else {
			return null;
		}

		foreach ($this->db->query($sql) as $row) {
			return new Group($row[0], $row[1], $row[2]);
		}
		return false;
	}
	
	static function getUserMembers($userId, $recursive = false) {
		self::$instance = self::getInstance();
		
		// check internal cache
		if (isset(self::$instance->cache[$userId][$recursive])) {
			Logger::Debug("AccessControlManager::getUserMembers()", "Reusing internal cache..");
			return self::$instance->cache[$userId][$recursive];
		}
		
		$groups = array();		
		$sql = "SELECT Groups.id, Groups.name, Groups.description FROM Groups, Members WHERE Groups.id = Members.groupId AND Members.type = 1 AND Members.member = $userId";
		foreach (self::$instance->db->query($sql) as $row) {
			$groups[] = new Group($row[0], $row[1], $row[2]);
		}
		
		// If recursive is set, we should find all groups based on the group
		if ($recursive) {
			$allGroups = array();
			foreach ($groups as $group) {
				if (!in_array($group, $allGroups)) {
					$allGroups[] = $group;
				}
				$subGroups = $group->getGroups();
				foreach ($subGroups as $subGroup) {
					if (!in_array($subGroup, $allGroups)) {
						$allGroups[] = $subGroup;
					}
				}
			}
			$groups = $allGroups;
		}
		
		// set internal cache
		self::$instance->cache[$userId] = array();
		self::$instance->cache[$userId][$recursive] = $groups;
		
		return $groups;		
		
	}

	static function getGroupMembers($groupId) {
		self::$instance = self::getInstance();
		
		$groups = array();		
		$sql = "SELECT Groups.id, Groups.name, Groups.description FROM Groups, Members WHERE Groups.id = Members.groupId AND Members.type = 2 AND Members.member = $groupId";
		foreach (self::$instance->db->query($sql) as $row) {
			$groups[] = new Group($row[0], $row[1], $row[2]);
		}
		return $groups;		
		
	}
	
	static function updateUser(&$user) {
		self::$instance = self::getInstance();
		
		if ($user->getId() == "") {
			$sql = "INSERT INTO Users VALUES (" .
			"null, " .
			"'" . $user->getUsername() . "', " .
			"'" . $user->getPassword() . "', " .
			"'" . $user->getName() . "', " .
			"'" . $user->getDivision() . "', " .
			($user->isAdmin() ? 1 : 0) . ", " .
			($user->isAgreement() ? 1 : 0) . ", " .
			($user->isTemplateUser() ? 1 : 0) . ", " .
			($user->isViewUser() ? 1 : 0) . ", " .			
			($user->isReportGeneratorUser() ? 1 : 0) . ", " .		
			($user->isReset() ? 1 : 0) .
			");";
		} else {
			$sql = "UPDATE Users SET " .
			"username = '" . $user->getUsername() . "', " .
			"password = '" . $user->getPassword() . "', " .
			"name = '" . $user->getName() . "', " .
			"division = '" . $user->getDivision() . "', " .
			"admin = " . ($user->isAdmin() ? 1 : 0) . ", " .
			"agreement = " . ($user->isAgreement() ? 1 : 0) . ", " .
			"templateUser = " . ($user->isTemplateUser() ? 1 : 0) . ", " .
			"viewUser = " . ($user->isViewUser() ? 1 : 0) . ", " .
			"reportGeneratorUser = " . ($user->isReportGeneratorUser() ? 1 : 0) . ", " .
			"isReset = " . ($user->isReset() ? 1 : 0). " " .
			"WHERE id = " . $user->getId() . ";";
		}
		
		if (!self::$instance->db->exec($sql)) return false;
		
		if ($user->getId() == "") {
			//die(self::$instance->db->lastInsertId());
			$user->setId(self::$instance->db->lastInsertId());
		}
		
		return true;
	}
	
	static function removeUser($userId) {
		if (empty($userId)) return false;
		
		self::$instance = self::getInstance();
		
		$sql = "DELETE FROM Users WHERE id = " . $userId . ";";
		if (!self::$instance->db->exec($sql)) return false;
		
		return true;
	}	
	
	static function removeGroup($groupId) {
		if (empty($groupId)) return false;
		
		self::$instance = self::getInstance();
		
		$sql = "DELETE FROM Groups WHERE id = " . $groupId . ";";
		if (!self::$instance->db->exec($sql)) return false;
                $sql = "DELETE FROM AnonymousAccess WHERE groupId = " . $groupId . ";";
                self::$instance->db->exec($sql);
		//if (!self::$instance->db->exec($sql)) return false;
                $sql = "DELETE FROM ClassificationValuesAccess WHERE groupId = " . $groupId . ";";
		self::$instance->db->exec($sql);
                $sql = "DELETE FROM ClassificationValuesRegularAccess WHERE groupId = " . $groupId . ";";
		self::$instance->db->exec($sql);
                $sql = "DELETE FROM DataTypeAccess WHERE groupId = " . $groupId . ";";
		self::$instance->db->exec($sql);
                $sql = "DELETE FROM FeatureAccess WHERE groupId = " . $groupId . ";";
		self::$instance->db->exec($sql);
                $sql = "DELETE FROM FolderAccess WHERE groupId = " . $groupId . ";";

        Logger::Info("AccessControlManager->RemoveGroup", $_SESSION['USER']->getName() . 'Remove Group' . $groupId . ' ' . $sql);

		self::$instance->db->exec($sql);
                $sql = "DELETE FROM Members WHERE groupId = " . $groupId . ";";
		self::$instance->db->exec($sql);
                $sql = "DELETE FROM ProductAccess WHERE groupId = " . $groupId . ";";
		self::$instance->db->exec($sql);
		
		return true;
	}

	static function updateGroup($group) {
		self::$instance = self::getInstance();
		
		if ($group->getId() == "") {
			$sql = "INSERT INTO Groups VALUES (null, '" . $group->getName() . "', '" . $group->getDescription() . "');";
		} else {
			$sql = "UPDATE Groups SET name = '" . $group->getName() . "', description = '" . $group->getDescription() . "' WHERE id = " . $group->getId() . ";";
			Logger::Info("AccessControlManager::updateGroup()", "SQL : " . $sql);
		}
		$return = self::$instance->db->exec($sql);
		if ($group->getId() == "") {
			$group->setId(self::$instance->db->lastInsertId());
		}
		return $return;
	}
	
	
	public function updateDataTypesInGroup($group, $datatypeIds) {
		if (!$group instanceof Group || $group->getId() == "") return;
		
		$existingIds = $this->getGroupDataTypes($group->getId(), true);
		
		// Set eveything to not visible first
		$sql = "UPDATE DataTypeAccess SET visible = 0 WHERE groupId = " . $group->getid() . ";";
		$this->db->exec($sql);
		
		foreach ($datatypeIds as $datatypeId) {
			if (in_array($datatypeId, $existingIds)) {
				$sql = "UPDATE DataTypeAccess SET visible = 1 WHERE groupId = " . $group->getid() . " AND datatypeId = " . $datatypeId . ";";
			} else {
				$sql = "INSERT INTO DataTypeAccess VALUES (null, " . $group->getid() . ", " . $datatypeId . ", 1);";
			}
			$this->db->exec($sql);
			Logger::Info("AccessControlManager::updateDataTypesInGroup()", "SQL : " . $sql);
		}
		
	}
	
	public function updateProductsInGroup($group, $products, $hproducts) {
		if (!$group instanceof Group || $group->getId() == "") return;
		

        $existingVisibleProds = $this->getGroupProducts($group->getId(), false);
		
        if($hproducts){
        	$sql = $this->db->prepare("DELETE FROM ProductAccess WHERE groupId = " . $group->getid() . " AND productName = :product");
        	$sql2 = $this->db->prepare("DELETE FROM FeatureAccess WHERE groupId = " . $group->getid() . " AND productName = :product");
			$this->db->beginTransaction();
			foreach ($hproducts as $product) {
				$sql->bindParam(':product', SQLite3::escapeString(stripslashes($product)));
				$sql->execute();

				$countfeat = count(DatabaseManager::getAllFeatureFromProduct($product));
				$countVfeat = count($this->getGroupFeatures($group->getId(), false, $product));

				if($countfeat == $countVfeat && $countVfeat > 0){
					$sql2->bindParam(':product', SQLite3::escapeString(stripslashes($product)));
					$sql2->execute();	
				}
			}
			$this->db->commit();
			Logger::Info("AccessControlManager::updateProductsInGroup()", "SQL : " . $sql);
        }

		if($products){
			$sql = $this->db->prepare("INSERT INTO ProductAccess VALUES (null, " . $group->getid() . ", :product, 1)");
			$sql2 = $this->db->prepare("INSERT INTO FeatureAccess VALUES (null, " . $group->getid() . ", :feature, 1, :product)");
			$this->db->beginTransaction();
			foreach ($products as $product) {
				if (!in_array(SQLite3::escapeString(stripslashes($product)), $existingVisibleProds)) {
					$sql->bindParam(':product', SQLite3::escapeString(stripslashes($product)));
					$sql->execute();
				}

				$features = DatabaseManager::getAllFeatureFromProduct($product);
				$existingVisibleFeats = $this->getGroupFeatures($group->getId(), false, $product);
				foreach ($features as $feature) {
					if (!in_array(SQLite3::escapeString(stripslashes($feature)), $existingVisibleFeats)) {
						$sql2->bindParam(':feature', SQLite3::escapeString(stripslashes($feature)));
						$sql2->bindParam(':product', SQLite3::escapeString(stripslashes($product)));
						$sql2->execute();	
					}
				}


			}
			$this->db->commit();
			Logger::Info("AccessControlManager::updateProductsInGroup()", "SQL : " . $sql);
		}		
	}
	
	public function updateFeaturesInGroup($group, $features, $hfeatures, $product) {
		if (!$group instanceof Group || $group->getId() == "") return;
        $existingVisibleFeats = $this->getGroupFeatures($group->getId(), false, $product);
		



        if($hfeatures){
        	$sql = $this->db->prepare("DELETE FROM FeatureAccess WHERE groupId = " . $group->getid() . " AND featureName = :feature AND productName = :product");
			$this->db->beginTransaction();
			foreach ($hfeatures as $feature) {
				$sql->bindParam(':feature', SQLite3::escapeString(stripslashes($feature)));
				$sql->bindParam(':product', SQLite3::escapeString(stripslashes($product)));
				$sql->execute();
			}
			$this->db->commit();
			Logger::Info("AccessControlManager::updateFeaturesInGroup()", "SQL : " . $sql);
        }
		
		if($features){
			$sql = $this->db->prepare("INSERT INTO FeatureAccess VALUES (null, " . $group->getid() . ", :feature, 1, :product)");
			$sql2 = $this->db->prepare("INSERT INTO ProductAccess VALUES (null, " . $group->getid() . ", :product, 1)");
			$this->db->beginTransaction();
			foreach ($features as $feature) {
				if (!in_array(SQLite3::escapeString(stripslashes($feature)), $existingVisibleFeats)) {
					$sql->bindParam(':product', SQLite3::escapeString(stripslashes($product)));
					$sql->bindParam(':feature', SQLite3::escapeString(stripslashes($feature)));
					$sql->execute();
				}

			}
			$this->db->commit();
			Logger::Info("AccessControlManager::updateFeaturesInGroup()", "SQL : " . $sql);
			
		}

	}

	// AccessControlManager::setAllHide - Insert all Product/Feature from ClassificationValue to Product/FeatureAccess for specified groupID 
	public function setAllHide($group, $values, $cvtype){
		if (!$group instanceof Group || $group->getId() == "") return;

		if($cvtype == "Feature"){
			$existingVisible = $this->getGroupFeatures($group->getId(), false);
		}
		else{
			$existingVisible = $this->getGroupProducts($group->getId(), false);
		}


		if(count($existingVisible) != count($values)){
			$this->setAllUnHide($group, $cvtype);
			$sql = $this->db->prepare("INSERT INTO " . $cvtype . "Access VALUES (null, " . $group->getid() . ", :value , 1)");
			$this->db->beginTransaction();
			foreach ($values as $value) {
				$sql->bindParam(':value', SQLite3::escapeString(stripslashes($value)));
				$sql->execute();	 
			}
			$this->db->commit();
			Logger::Info("AccessControlManager::setAllHide()", "SQL : " . $sql);
		}
	}

	// AccessControlManager::setAllUnHide - Delete all Product/FeatureAccess for specified groupID 
	public function setAllUnHide($group, $cvtype){
		if (!$group instanceof Group || $group->getId() == "") return;
		
		$sql = "DELETE FROM " . $cvtype . "Access WHERE groupId = " . $group->getid() . ";";
        $this->db->exec($sql);
        Logger::Info("AccessControlManager::setAllUnHide()", "SQL : " . $sql);
	}
	
	public function updateFoldersInGroup($group, $folders) {
		if (!$group instanceof Group || $group->getId() == "") return;
		
		// Remove all groups first, then add all again
		$sql = "DELETE FROM FolderAccess WHERE groupId = " . $group->getid() . ";";
		$this->db->exec($sql);

		// Logger info
		Logger::Info("AccessControlManager->updateFoldersInGroup", $_SESSION['USER']->getName() . ' Edited Group ' . $group->getName() . ' ' . $sql);
		
		foreach ($folders as $folder) {
			$sql = "INSERT INTO FolderAccess VALUES (null, " . $group->getid() . ", '" . $folder. "');";
			$this->db->exec($sql);
			// Logger info
			Logger::Info("AccessControlManager->updateFoldersInGroup", $_SESSION['USER']->getName() . ' Edited Group ' . $group->getName() . ' ' . $sql);
		}
	}

	public function isProductHidden($product, $groupId){
		// Select the ProductAccess if hidden
    	$sql = "SELECT productName, groupId FROM ProductAccess WHERE productName = '" . $product . "' AND groupId = " . $groupId;
    	
    	$counter = 0;
		foreach (self::$instance->db->query($sql) as $row) {
			$counter++;
		}
		if ($counter > 0) {
			return true;
		} else {
			return false;
		}
        Logger::Info("AccessControlManager::isProductHidden()", "SQL : " . $counter);
	}

	public function isFeatureHidden($product, $feature, $groupId){
		// Default Hidden Features
		$defaultHiddenFeature = " AND featureName NOT LIKE 'Slb_Internal%' AND featureName NOT LIKE 'Petrel_Bo%' ";
		// Select the FeatureAccess if hidden
    	$sql = "SELECT productName, featureName, groupId FROM FeatureAccess WHERE productName = '" . $product . "' AND featureName = '" . $feature . "' AND groupId = " . $groupId . $defaultHiddenFeature;
    	
    	$counter = 0;
		foreach (self::$instance->db->query($sql) as $row) {
			$counter++;
		}

		if ($counter > 0) {
			return true;
		} else {
			return false;
		}
        Logger::Info("AccessControlManager::isFeatureHidden()", "SQL : " . $counter);
	}
	
	public function deleteFolder($folder) {
		// Remove all groups first, then add all again
		$sql = "DELETE FROM FolderAccess WHERE folder = '" . $folder->getName() . "';";
		$this->db->exec($sql);
		$sql = "DELETE FROM Folders WHERE name = '" . $folder->getName() . "';";
		$this->db->exec($sql);

		Logger::Info("AccessControlManager->deleteFolder", $_SESSION['USER']->getName() . ' Deleting Folder ' . $folder->getName());

	}
	
	public static function getGroupDataTypes($groupId, $all = true) {
		$existingIds = array();
		if ($all) {
			$sql = "SELECT datatypeId FROM DataTypeAccess WHERE groupId = " . $groupId;
		} else {
			$sql = "SELECT datatypeId FROM DataTypeAccess WHERE visible = 1 AND groupId = " . $groupId;
		}
		foreach (self::$instance->db->query($sql) as $row) {
			$existingIds[] = $row[0];
		}
		return $existingIds;		
	}
	
	public static function getGroupProducts($groupId, $all = true) {
		$existingProds = array();
		if ($all) {
			$sql = "SELECT productName FROM ProductAccess WHERE groupId = " . $groupId;
		} else {
			$sql = "SELECT productName FROM ProductAccess WHERE visible = 1 AND groupId = " . $groupId;
		}
		
		foreach (self::$instance->db->query($sql) as $row) {
			$existingProds[] = $row[0];
		}
		return $existingProds;		
	}

	public static function getGroupFeatures($groupId, $all = true, $product = NULL) {
		$existingFeats = array();
		// Default Hidden Features
		$defaultHiddenFeature = " AND featureName NOT LIKE 'Slb_Internal%' AND featureName NOT LIKE 'Petrel_Bo%' ";

		if ($all) {
			$sql = "SELECT featureName FROM FeatureAccess WHERE groupId = " . $groupId . $defaultHiddenFeature;
		} 
		else if($all == false && $product != NULL){
			if(is_array($product)){
				$sql = "SELECT featureName FROM FeatureAccess WHERE visible = 1 AND groupId = " . $groupId . $defaultHiddenFeature . " AND productName IN ('" . self::getProductArray($product) . "')";
			}
			else{
				$sql = "SELECT featureName FROM FeatureAccess WHERE visible = 1 AND groupId = " . $groupId . $defaultHiddenFeature . " AND productName = '" . $product . "'";
			}
		}
		else {
			if(is_array($groupId)){
				// If groupId is an array
				$groupId = implode(', ', $groupId);
				$sql = "SELECT featureName FROM FeatureAccess WHERE visible = 1 AND groupId IN (" . $groupId . ")" . $defaultHiddenFeature;
			} else {
				// If groupId is not an array
				$sql = "SELECT featureName FROM FeatureAccess WHERE visible = 1 AND groupId = " . $groupId . $defaultHiddenFeature;
			}
		}

		foreach (self::$instance->db->query($sql) as $row) {
			$existingFeats[] = $row[0];
		}
		
		return $existingFeats;		
	}

	public function getProductArray($product){
		//This will join the array products with a string
		foreach ($product as $prod) {
			if($prod->isSelected()){
				$prod_array[] = $prod->getValue();
			}else{
				$prod_array_unselected[] = $prod->getValue();
			}
		}

		if(count($prod_array) > 0){
			return implode('\',\'', $prod_array);	
		}else{
			return implode('\',\'', $prod_array_unselected);
		}

	}
	
	public static function getGroupFolder($groupId) {
		$folders = array();
		$sql = "SELECT folder FROM FolderAccess WHERE groupId = " . $groupId;
		
		Logger::Info("AccessControlManager->getGroupFolder", $_SESSION['USER']->getName() . 'Group Folder Access' . $groupId . ' ' . $sql);

		foreach (self::$instance->db->query($sql) as $row) {
			$folders[] = $row[0];
			Logger::Info("AccessControlManager->getGroupFolder", $_SESSION['USER']->getName() . 'Folder List - ' . $row[0]);
		}
		return $folders;
	}
	
	public function removeMembersFromUser($user) {
		if (!$user instanceof User || $user->getId() == "") return;
		$sql = "DELETE FROM Members WHERE Members.type = 1 AND Members.member = " . $user->getId();
		$this->db->exec($sql);
	}
	
	public function addMembersFromUser($user, $groupIds) {
		if ($user->getId() == "") return;

		// Remove all members first
		$sql = "DELETE FROM Members WHERE type = 1 AND member = " . $user->getId() . "\n";
		$this->db->exec($sql);
		
		Logger::Info("AccessControlManager->addMembersFromUser", $_SESSION['USER']->getName() . 'Edited User' . $user->getName() . ' ' . $sql);

		$sql = "BEGIN;\n";
		foreach ($groupIds as $groupId) {
			$sql .= "INSERT INTO Members VALUES (null, " . $groupId . ", 1, " . $user->getId() . ");\n";
			Logger::Info("AccessControlManager->addMembersFromUser", $_SESSION['USER']->getName() . 'Edited User (Insert)' . $groupId . ' ' . $sql);
		}
		$sql .= "COMMIT;\n";
		$this->db->exec($sql);

		Logger::Info("AccessControlManager->addMembersFromUser", $_SESSION['USER']->getName() . 'Edited User' . $user->getName() . ' ' . $sql);		
	}

	public function addMembersFromGroup($group, $groupIds) {
		if ($group->getId() == "") return;
		
		// Remove all members first
		$sql = "DELETE FROM Members WHERE type = 2 AND member = " . $group->getId() . "\n";
		$this->db->exec($sql);
		
		// Logger info
		Logger::Info("AccessControlManager->addMembersFromGroup", $_SESSION['USER']->getName() . ' Edited Group ' . $group->getName() . ' ' . $sql);

		$sql = "BEGIN;\n";
		foreach ($groupIds as $groupId) {
			$sql .= "INSERT INTO Members VALUES (null, " . $groupId . ", 2, " . $group->getId() . ");\n";
			Logger::Info("AccessControlManager->addMembersFromGroup", $_SESSION['USER']->getName() . 'Edited Group (Insert)' . $groupId . ' ' . $sql);
		}
		$sql .= "COMMIT;\n";
		$this->db->exec($sql);
		// Logger info
		Logger::Info("AccessControlManager->addMembersFromGroup", $_SESSION['USER']->getName() . ' Edited Group ' . $group->getName() . ' ' . $sql);
	}
	
	function updateAnonymousClassificationInGroup($group, $datatypeId, $classificationId, $checked) {

		if ($checked) {
			$sql = "INSERT INTO AnonymousAccess VALUES (null, " . $group->getId() . ", " . $datatypeId . ", " . $classificationId . ");\n";
		} else {
			$sql = "DELETE FROM AnonymousAccess WHERE groupId = " . $group->getId() . " AND datatypeId = " . $datatypeId . " AND classificationId = " . $classificationId . ";\n";
		}
		$this->db->exec($sql);
		//echo $sql;
	}
	
	public static function getAnonymousClassificationInGroup($group) {
		self::$instance = self::getInstance();
		$anonymousClassifications = array();
		
		$sql = "SELECT datatypeId, classificationId FROM AnonymousAccess WHERE groupId = '" . $group->getId() . "'";
		foreach (self::$instance->db->query($sql) as $row) {
			if (!isset($anonymousClassifications[$row[0]])) {
				$anonymousClassifications[$row[0]] = array();
			}
			$anonymousClassifications[$row[0]][] = $row[1];
		}
		return $anonymousClassifications;
	}
	
	public static function getContentLimit($group) {
		self::$instance = self::getInstance();
		
		$contentLimits = array();		

		$sql = "SELECT datatypeId, value FROM ClassificationValuesAccess WHERE groupId = '" . $group->getId() . "'";
		foreach (self::$instance->db->query($sql) as $row) {
			if (!isset($anonymousClassifications[$row[0]])) {
				$anonymousClassifications[$row[0]] = array();
			}
			$anonymousClassifications[$row[0]][] = $row[1];
		}
				
		return $contentLimits;
	}
	
	
	/* Check if a password match a user profile */
	public static function isPasswordCorrect(User &$user, $password) {
		
		$userPasswordMatch = false;
		
		switch (ServerConfig::getPasswordBackend()) {
			
			case AccessControlManager::PASSWORDBACKEND_AD:				
				$ldapSearcher = new LDAPSearcher();
				$ldapSearcher->setAd(true);
				$ldapSearcher->setServer("192.168.7.10");
				$ldapSearcher->setSuffix("@svg.openit.local");
				$ldapSearcher->setBaseDn("dc=svg,dc=openit,dc=local");
				$ldapSearcher->setUsername($user->getUsername());
				$ldapSearcher->setPassword($password);
				
				if ($ldapSearcher->connect() && $ldapSearcher->authorize()) {
					$searchUser = $ldapSearcher->getUser($user->getUsername());
					$user->setName($searchUser->getName());					
					return true;
				}				
				break;
				
			case AccessControlManager::PASSWORDBACKEND_LDAP:
				break;
				
			case AccessControlManager::PASSWORDBACKEND_LOCAL:
				if ($user->getPassword() == md5($password)) {
					return true;
				}
				break;
				
		}
		
		// If user is not accepeted, and using something else than local and is admin, we try local as well
		if (!$userPasswordMatch &&
			ServerConfig::getPasswordBackend() !=  AccessControlManager::PASSWORDBACKEND_LOCAL &&
			$user->getUsername() == "admin"
			) {
			$userPasswordMatch = $user->getPassword() == md5($password) ? true : false;
		}
		
		return $userPasswordMatch;
	}
	
	/* Check if a password match a user profile */
	public static function getLDAPUser($username) {
		
		switch (ServerConfig::getPasswordBackend()) {
			
			case AccessControlManager::PASSWORDBACKEND_AD:				
				$ldapSearcher = new LDAPSearcher();
				$ldapSearcher->setAd(true);
				$ldapSearcher->setServer("192.168.7.10");
				$ldapSearcher->setSuffix("@svg.openit.local");
				$ldapSearcher->setBaseDn("dc=svg,dc=openit,dc=local");
				$ldapSearcher->setUsername("cerberus");
				$ldapSearcher->setPassword("Hvd0bd#5");
				
				if ($ldapSearcher->connect() && $ldapSearcher->authorize()) {
					return $ldapSearcher->getUser($username);
				}
				return null;				
				break;
				
			case AccessControlManager::PASSWORDBACKEND_LDAP:
				return null;
				break;
				
			case AccessControlManager::PASSWORDBACKEND_LOCAL:
			default:
				return null;
				break;
		}
		return null;				
	}
	
	
}

?>